@@ -1,6 +1,5 @@
 from .mlp import MLPLayer
 from .lstmp import LSTMPCell, LSTMP
-from .multi_lstmp import MultiLSTMP
 from .bert_tokenization import BertTokenizationLayer
 from .bert_layer import (
     BertEncodeLayer,
@@ -16,7 +15,6 @@ __all__ = [
     "MLPLayer",
     "LSTMPCell",
     "LSTMP",
-    "MultiLSTMP",
     "BertTokenizationLayer",
     "BertEncodeLayer",
     "BertPreprocessingLayer",
