@@ -321,7 +321,7 @@ class BertEncodeLayer(tf.keras.layers.Layer):
             "activation": self.activation,
             "dropout_rate": self.dropout_rate,
             "attention_dropout_rate": self.attention_dropout_rate,
-            "initializer": tf.keras.initializers.serialize(self.initializer),
+            "initializer": self.initializer,
             "share_layer": self.share_layer,
             "cls_pooling": self.cls_pooling,
         }
\ No newline at end of file
