@@ -21,8 +21,6 @@ class MultiLabelCategoricalCrossentropy(tf.keras.losses.Loss):
     def call(self, y_true: tf.Tensor, y_pred: tf.Tensor) -> tf.Tensor:
         if isinstance(y_pred, tf.RaggedTensor):
             y_pred = y_pred.to_tensor(y_pred.dtype.min)
-        else:
-            y_pred = tf.convert_to_tensor(y_pred)
         y_true = tf.cast(y_true, y_pred.dtype)
 
         sample_size = tf.reduce_prod(tf.shape(y_true)[: self.flatten_axis])
@@ -39,4 +37,4 @@ class MultiLabelCategoricalCrossentropy(tf.keras.losses.Loss):
         return neg_loss + pos_loss
 
     def get_config(self) -> dict[str, Any]:
-        return {**super().get_config(), "flatten_axis": self.flatten_axis}
+        return {**super().get_config(), "flatten_axis": self.flatten_axis}
\ No newline at end of file
