@@ -1,3 +1,3 @@
 from .text2vec import Text2vec
 from .word2vec import Word2vec
-from .bert2vec import Bert2vec, Albert2vec
+from .bert2vec import Bert2vec
